# Changelog

## [6.0.0a1](https://github.com/OpenVoiceOS/ovos-workshop/tree/6.0.0a1) (2025-06-07)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-workshop/compare/5.0.1...6.0.0a1)

**Breaking changes:**

- refactor!: stop [\#344](https://github.com/OpenVoiceOS/ovos-workshop/pull/344) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
